@@ -1,20 +1,8 @@
-/*****************************************************************************
- * Copyright (c) 2010-2011 Sven Brauch <svenbrauch@googlemail.com>           *
- *                                                                           *
- * This program is free software; you can redistribute it and/or             *
- * modify it under the terms of the GNU General Public License as            *
- * published by the Free Software Foundation; either version 2 of            *
- * the License, or (at your option) any later version.                       *
- *                                                                           *
- * This program is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             *
- * GNU General Public License for more details.                              *
- *                                                                           *
- * You should have received a copy of the GNU General Public License         *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.     *
- *****************************************************************************
- */
+/*
+    SPDX-FileCopyrightText: 2010-2011 Sven Brauch <svenbrauch@googlemail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "worker.h"
 #include "model.h"
@@ -68,3 +56,5 @@ void PythonCodeCompletionWorker::updateContextRange(KTextEditor::Range &contextR
 
 
 }
+
+#include "moc_worker.cpp"
