@@ -1,23 +1,8 @@
 /*
- * Copyright 2016  Sven Brauch <mail@svenbrauch.de>
- * 
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- * 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- * 
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
- */
+    SPDX-FileCopyrightText: 2016 Sven Brauch <mail@svenbrauch.de>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "pythonstylechecking.h"
 
@@ -28,8 +13,11 @@
 #include <language/duchain/problem.h>
 #include <language/editor/documentrange.h>
 #include <interfaces/icore.h>
+
 #include <shell/documentcontroller.h>
 
+#include <KTextEditor/Document>
+
 #include "pythondebug.h"
 #include "pythonparsejob.h"
 #include "helpers.h"
@@ -46,8 +34,8 @@ StyleChecking::StyleChecking(QObject* parent)
             [this]() {
                 qWarning() << "python code checker error:" << m_checkerProcess.readAllStandardError();
             });
-    auto config = KSharedConfig::openConfig("kdevpythonsupportrc");
-    m_pep8Group = config->group("pep8");
+    auto config = KSharedConfig::openConfig(QStringLiteral("kdevpythonsupportrc"));
+    m_pep8Group = config->group(QStringLiteral("pep8"));
 }
 
 StyleChecking::~StyleChecking()
@@ -64,7 +52,7 @@ void StyleChecking::startChecker(const QString& text, const QString& select,
     // start up the server
     if ( m_checkerProcess.state() == QProcess::NotRunning ) {
         auto python = Helper::getPythonExecutablePath(nullptr);
-        auto serverPath = QStandardPaths::locate(QStandardPaths::GenericDataLocation, "kdevpythonsupport/codestyle.py");
+        auto serverPath = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kdevpythonsupport/codestyle.py"));
         if ( serverPath.isEmpty() ) {
             qWarning() << "setup problem: codestyle.py not found";
             m_mutex.unlock();
@@ -96,7 +84,7 @@ void StyleChecking::startChecker(const QString& text, const QString& select,
 
 void StyleChecking::addErrorsToContext(const QVector<QString>& errors)
 {
-    static QRegularExpression errorFormat("(.*):(\\d*):(\\d*): (.*)", QRegularExpression::CaseInsensitiveOption);
+    static QRegularExpression errorFormat(QStringLiteral("(.*):(\\d*):(\\d*): (.*)"), QRegularExpression::CaseInsensitiveOption);
     DUChainWriteLocker lock;
     auto document = m_currentlyChecking->url();
     for ( const auto& error : errors ) {
@@ -115,7 +103,7 @@ void StyleChecking::addErrorsToContext(const QVector<QString>& errors)
             p->setFinalLocation(DocumentRange(document, KTextEditor::Range(lineno - 1, qMax(colno - 1, 0),
                                                                            lineno - 1, colno)));
             p->setSource(KDevelop::IProblem::Preprocessor);
-            p->setSeverity(error.startsWith('W') ? KDevelop::IProblem::Hint : KDevelop::IProblem::Warning);
+            p->setSeverity(error.startsWith(QLatin1Char('W')) ? KDevelop::IProblem::Hint : KDevelop::IProblem::Warning);
             p->setDescription(i18n("PEP8 checker error: %1", error));
             ProblemPointer ptr(p);
             m_currentlyChecking->addProblem(ptr);
@@ -130,13 +118,28 @@ void StyleChecking::addErrorsToContext(const QVector<QString>& errors)
 
 void StyleChecking::processOutputStarted()
 {
+    if (m_mutex.try_lock()) {
+        // The m_mutex (which is *not* recursive) was not locked!!
+        // This probably means there is some problem with the
+        // checker server, which is sending us more data than
+        // we expected (or consumed). The only way we can deal
+        // with this situation is to kill the server and start it
+        // again, when needed
+        if ( m_checkerProcess.state() == QProcess::Running ) {
+            m_checkerProcess.terminate();
+            m_checkerProcess.waitForFinished(100);
+        }
+        m_mutex.unlock();
+        return;
+    }
+
     // read output size
     QByteArray size_d;
     size_d = m_checkerProcess.read(10);
     bool ok;
     auto size = size_d.toInt(&ok);
     if ( !ok || size < 0 ) {
-        addSetupErrorToContext("Got invalid size: " + size_d);
+        addSetupErrorToContext(QStringLiteral("Got invalid size: ") + QString::fromLatin1(size_d));
         m_mutex.unlock();
         return;
     }
@@ -158,10 +161,10 @@ void StyleChecking::processOutputStarted()
     auto ofs = -1;
     auto prev = ofs;
     while ( prev = ofs, (ofs = buf.indexOf('\n', ofs+1)) != -1 ) {
-        errors.append(buf.mid(prev+1, ofs-prev));
+        errors.append(QString::fromLatin1(buf.mid(prev+1, ofs-prev)));
     }
     if ( !t.isActive() ) {
-        addSetupErrorToContext("Output took longer than 100 ms.");
+        addSetupErrorToContext(QStringLiteral("Output took longer than 100 ms."));
     }
     addErrorsToContext(errors);
 
@@ -190,8 +193,8 @@ void StyleChecking::updateStyleChecking(const KDevelop::ReferencedTopDUContext&
 
     // default empty is ok, it will never be used, because the config has to be written at least once
     // to even enable this feature.
-    auto select = m_pep8Group.readEntry<QString>("enableErrors", "");
-    auto ignore = m_pep8Group.readEntry<QString>("disableErrors", "");
+    auto select = m_pep8Group.readEntry<QString>("enableErrors", QString());
+    auto ignore = m_pep8Group.readEntry<QString>("disableErrors",QString());
     auto maxLineLength = m_pep8Group.readEntry<int>("maxLineLength", 80);
     startChecker(text, select, ignore, maxLineLength);
 }
@@ -203,9 +206,11 @@ void StyleChecking::addSetupErrorToContext(const QString& error)
     p->setFinalLocation(DocumentRange(m_currentlyChecking->url(), KTextEditor::Range(0, 0, 0, 0)));
     p->setSource(KDevelop::IProblem::Preprocessor);
     p->setSeverity(KDevelop::IProblem::Warning);
-    p->setDescription(i18n("The PEP8 syntax checker does not seem to work correctly.") + "\n" + error);
+    p->setDescription(i18n("The PEP8 syntax checker does not seem to work correctly.") + QStringLiteral("\n") + error);
     ProblemPointer ptr(p);
     m_currentlyChecking->addProblem(ptr);
 }
 
 };
+
+#include "moc_pythonstylechecking.cpp"
